@@ -1,9 +1,10 @@
 
 """Loadable fixture components"""
 
-__all__ = ['SQLAlchemyFixture', 'SQLObjectFixture']
+__all__ = ['SQLAlchemyFixture', 'SQLObjectFixture', 'GoogleDatastoreFixture']
 import loadable
 __doc__ = loadable.__doc__
 from loadable import *
 from sqlalchemy_loadable import SQLAlchemyFixture
-from sqlobject_loadable import SQLObjectFixture
\ No newline at end of file
+from sqlobject_loadable import SQLObjectFixture
+from google_datastore_loadable import GoogleDatastoreFixture
\ No newline at end of file
